try:
    import swcli.settings as settings
    import swcli.utils as utils
    from swcli.models import Planet
except:
    import settings
    import utils
    from models import Planet
from httpx import get


class GetSpecie(object):
    def get_specie_by_id(specie_id):
        """
        Return a one or many species on Star Wars trilogies by ID.
        """
        response = get(
            settings.BASE_URL +
            settings.SPECIES +
            str(specie_id))

        if response.status_code != 200:
            raise SystemExit('Resource does not exist!')

        json_data = response.json()

        homeworld = get(json_data['homeworld']).json()['name']

        species_response = {
            "name": json_data['name'],
            "classification": json_data['classification'],
            "designation": json_data['designation'],
            "average_height": int(json_data['average_height']) / 100,
            "average_lifespan": json_data['average_lifespan'],
            "eye_colors": json_data['eye_colors'],
            "hair_colors": json_data['hair_colors'],
            "skin_colors": json_data['skin_colors'],
            "language": json_data['language'],
            "homeworld": homeworld,
            "people": utils.get_resources_dict(
                json_data['people'],
                'name'),
            "films": utils.get_resources_dict(
                json_data['films'],
                'title'),
        }

        specie = Specie(**species_response)
        yield specie.json(ensure_ascii=False, encoder='utf-8')

    def get_specie_by_name(name):
        """
        Returns a specie on the Star Wars movies by searching name.
        """
        json_data = get(
            settings.BASE_URL +
            settings.SPECIES +
            settings.SEARCH +
            name).json()

        if not json_data['results']:
            raise SystemExit('Resource does not exist!')

        for json_dict in json_data['results']:
            homeworld = get(json_dict['homeworld']).json()['name']

            species_response = {
                "name": json_dict['name'],
                "classification": json_dict['classification'],
                "designation": json_dict['designation'],
                "average_height": int(json_dict['average_height']) / 100,
                "average_lifespan": json_dict['average_lifespan'],
                "eye_colors": json_dict['eye_colors'],
                "hair_colors": json_dict['hair_colors'],
                "skin_colors": json_dict['skin_colors'],
                "language": json_dict['language'],
                "homeworld": homeworld,
                "people": utils.get_resources_dict(
                    json_dict['people'],
                    'name'),
                "films": utils.get_resources_dict(
                    json_dict['films'],
                    'title'),
            }

        specie = Specie(**species_response)
        yield specie.json(ensure_ascii=False, encoder='utf-8')



from httpx import get


def get_resources_dict(resource, label):
    resources_list = []
    for r in resource:
        resource_itens = get(r).json()[label]
        resources_list.append(resource_itens)
    return resources_list



# -*- coding: utf-8 -*-

'''
Settings and stuff.
'''

BASE_URL = 'https://swapi.dev/api'
PEOPLE = '/people/'
PLANETS = '/planets/'
STARSHIPS = '/starships/'
VEHICLES = '/vehicles/'
FILMS = '/films/'
SPECIES = '/species/'
SEARCH = '?search='



from pydantic import BaseModel
from typing import List


class Film(BaseModel):
    title: str
    episode: str
    director: str
    producer: str
    release_date: str
    species: List[str]
    starships: List[str]
    vehicles: List[str]
    characters: List[str]
    planets: List[str]


class Person(BaseModel):
    name: str
    height: float
    mass: str
    hair_color: str
    skin_color: str
    birth_year: str
    gender: str
    homeworld: str
    films: List[str]
    vehicles: List[str]
    starships: List[str]


class Planet(BaseModel):
    name: str
    diameter: int
    rotation_period: int
    orbital_period: int
    gravity: str
    population: int
    climate: str
    terrain: str
    surface_water: str
    residents: List[str]
    films: List[str]


class Specie(BaseModel):
    name: str
    classification: str
    designation: str
    average_height: str
    average_lifespan: str
    eye_colors: str
    hair_colors: str
    skin_colors: str
    language: str
    homeworld: str
    people: List[str]
    films: List[str]


class Starship(BaseModel):
    name: str
    model: str
    starship_class: str
    manufacturer: str
    cost: str
    length: str
    crew: str
    passengers: str
    max_atmosphering_speed: str
    hyperdrive_rating: str
    mglt: str
    cargo_capacity: str
    consumables: str
    films: List[str]
    pilots: List[str]


class Vehicle(BaseModel):
    name: str
    model: str
    vehicle_class: str
    manufacturer: str
    length: str
    cost: str
    crew: str
    passengers: str
    max_atmosphering_speed: str
    cargo_capacity: str
    consumables: str
    films: List[str]
    pilots: List[str]



try:
    import swcli.settings as settings
    import swcli.utils as utils
    from swcli.models import Person
except:
    import settings
    import utils
    from models import Person
from httpx import get


class GetPerson():
    def get_person_by_id(person_id):
        """
        Returns a character on the Star Wars movies by searching ID.
        Like: Luke, Leia, Anakin, etc.
        """
        response = get(
            settings.BASE_URL +
            settings.PEOPLE +
            str(person_id))

        if response.status_code != 200:
            raise SystemExit('Resource does not exist!')

        json_data = response.json()

        homeworld = get(json_data['homeworld']).json()['name']

        character_response = {
            "name": json_data['name'],
            "height": int(
                json_data['height']) / 100,
            "mass": json_data['mass'],
            "hair_color": json_data['hair_color'],
            "skin_color": json_data['skin_color'],
            "birth_year": json_data['birth_year'],
            "gender": json_data['gender'],
            "homeworld": homeworld,
            "films": utils.get_resources_dict(
                json_data['films'],
                'title'),
            "vehicles": utils.get_resources_dict(
                json_data['vehicles'],
                'name'),
            "starships": utils.get_resources_dict(
                json_data['starships'],
                'name'),
        }

        person = Person(**character_response)
        yield person.json(ensure_ascii=False, encoder='utf-8')

    def get_person_by_name(name):
        """
        Returns a character on the Star Wars movies by searching name.
        """
        json_data = get(
            settings.BASE_URL +
            settings.PEOPLE +
            settings.SEARCH +
            name).json()

        if not json_data['results']:
            raise SystemExit('Resource does not exist!')

        for json_dict in json_data['results']:
            homeworld = get(json_dict['homeworld']).json()['name']

            character_response = {
                "name": json_dict['name'],
                "height": int(
                    json_dict['height']) / 100,
                "mass": json_dict['mass'],
                "hair_color": json_dict['hair_color'],
                "skin_color": json_dict['skin_color'],
                "birth_year": json_dict['birth_year'],
                "gender": json_dict['gender'],
                "homeworld": homeworld,
                "films": utils.get_resources_dict(
                    json_dict['films'],
                    'title'),
                "vehicles": utils.get_resources_dict(
                    json_dict['vehicles'],
                    'name'),
                "starships": utils.get_resources_dict(
                    json_dict['starships'],
                    'name'),
            }

            person = Person(**character_response)
            yield person.json(ensure_ascii=False, encoder='utf-8')



import fire
try:
    from swcli.films import GetFilm
    from swcli.people import GetPerson
    from swcli.planets import GetPlanet
    from swcli.species import GetSpecie
    from swcli.starships import GetStarship
    from swcli.vehicles import GetVehicle
except:
    from films import GetFilm
    from people import GetPerson
    from planets import GetPlanet
    from species import GetSpecie
    from starships import GetStarship
    from vehicles import GetVehicle


def films(id='', title=''):
    """
    Return a one or many movies on Star Wars trilogies by Title.
    """
    try:
        if id != '' and title == '':
            response = GetFilm.get_film_by_id(id)
        elif title != '' and id == '':
            response = GetFilm.get_film_by_title(title)
        return response
    except BaseException:
        raise SystemExit('Invalid search!')


def people(id='', name=''):
    """
    Returns a character on the Star Wars movies.
    Like: Luke, Leia, Anakin, etc.
    """
    try:
        if id != '' and name == '':
            response = GetPerson.get_person_by_id(id)
        elif name != '' and id == '':
            response = GetPerson.get_person_by_name(name)
        return response
    except BaseException:
        raise SystemExit('Invalid search!')


def planets(id='', name=''):
    """
    Return a planet.
    Like: Hoth, Naboo, etc.
    """
    try:
        if id != '' and name == '':
            response = GetPlanet.get_planet_by_id(id)
        elif name != '' and id == '':
            response = GetPlanet.get_planets_by_name(name)
        return response
    except BaseException:
        raise SystemExit('Invalid search!')


def species(id='', name=''):
    """
    Return a species on the Star Wars universe.
    Like: Wookie, Human, etc.
    """
    try:
        if id != '' and name == '':
            response = GetSpecie.get_specie_by_id(id)
        elif name != '' and id == '':
            response = GetSpecie.get_specie_by_name(name)
        return response
    except BaseException:
        raise SystemExit('Invalid search!')


def starships(id='', name=''):
    """
    Return a Starships on Star Wars universe.
    Like: Death Star, Millenium Falcon, etc.
    """
    try:
        if id != '' and name == '':
            response = GetStarship.get_starship_by_id(id)
        elif name != '' and id == '':
            response = GetStarship.get_starship_by_name(name)
        return response
    except BaseException:
        raise SystemExit('Invalid search!')


def vehicles(id='', name=''):
    """
    Return a vehicle used on Star Wars universe.
    Like: TIE Fighter, Geonosian starfighter, etc.
    """
    try:
        if id != '' and name == '':
            response = GetVehicle.get_vehicle_by_id(id)
        elif name != '' and id == '':
            response = GetVehicle.get_vehicle_by_name(name)
        return response
    except BaseException:
        raise SystemExit('Invalid search!')


def main():
    fire.Fire({
        'films': films,
        'people': people,
        'planets': planets,
        'species': species,
        'starships': starships,
        'vehicles': vehicles,
    })


if __name__ == '__main__':
    main()



try:
    import swcli.settings as settings
    import swcli.utils as utils
    from swcli.models import Film
except:
    import settings
    import utils
    from models import Film
from httpx import get


class GetFilm():
    def get_film_by_id(film_id):
        """
        Return a one or many movies on Star Wars trilogies by ID.
        """
        response = get(
            settings.BASE_URL +
            settings.FILMS +
            str(film_id))

        if response.status_code != 200:
            raise SystemExit('Resource does not exist!')

        json_data = response.json()

        film_response = {
            "title": json_data['title'],
            "episode": json_data['episode_id'],
            "director": json_data['director'],
            "producer": json_data['producer'],
            "release_date": json_data['release_date'],
            "species": utils.get_resources_dict(
                json_data['species'],
                'name'),
            "starships": utils.get_resources_dict(
                json_data['starships'],
                'name'),
            "vehicles": utils.get_resources_dict(
                json_data['vehicles'],
                'name'),
            "characters": utils.get_resources_dict(
                json_data['characters'],
                'name'),
            "planets": utils.get_resources_dict(
                json_data['planets'],
                'name'),
        }
        film = Film(**film_response)
        yield film.json(ensure_ascii=False, encoder='utf-8')

    def get_film_by_title(title):
        """
        Return a one or many movies on Star Wars trilogies by Title.
        """
        json_data = get(
            swcli.settings.BASE_URL +
            swcli.settings.FILMS +
            swcli.settings.SEARCH +
            title).json()

        if not json_data['results']:
            raise SystemExit('Resource does not exist!')

        for json_dict in json_data['results']:
            film_response = {
                "title": json_dict['title'],
                "episode": json_dict['episode_id'],
                "director": json_dict['director'],
                "producer": json_dict['producer'],
                "release_date": json_dict['release_date'],
                "species": utils.get_resources_dict(
                    json_dict['species'],
                    'name'),
                "starships": utils.get_resources_dict(
                    json_dict['starships'],
                    'name'),
                "vehicles": utils.get_resources_dict(
                    json_dict['vehicles'],
                    'name'),
                "characters": utils.get_resources_dict(
                    json_dict['characters'],
                    'name'),
                "planets": utils.get_resources_dict(
                    json_dict['planets'],
                    'name'),
            }

            film = Film(**film_response)
            yield film.json(ensure_ascii=False, encoder='utf-8')



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['swcli']

package_data = \
{'': ['*']}

install_requires = \
['autopep8>=1.5.7,<2.0.0',
 'fire>=0.4.0,<0.5.0',
 'httpx>=0.20.0,<0.21.0',
 'pydantic>=1.8.2,<2.0.0']

entry_points = \
{'console_scripts': ['swcli = swcli.swcli:main']}

setup_kwargs = {
    'name': 'swcli',
    'version': '0.1.9',
    'description': 'A simple CLI to do queries in StarWars API.',
    'long_description': None,
    'author': 'Pery Lemke',
    'author_email': 'pery.lemke@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



try:
    import swcli.settings as settings
    import swcli.utils as utils
    from swcli.models import Planet
except:
    import settings
    import utils
    from models import Planet
from httpx import get


class GetPlanet():
    def get_planet_by_id(planet_id):
        """
        Returns a planet on the Star Wars movies by searching ID.
        Like: Naboo, Coruscant, etc.
        """
        response = get(
            settings.BASE_URL +
            settings.PLANETS +
            str(planet_id))

        if response.status_code != 200:
            raise SystemExit('Resource does not exist!')

        json_data = response.json()

        planet_response = {
            "name": json_data['name'],
            "diameter": json_data['diameter'],
            "rotation_period": json_data['rotation_period'],
            "orbital_period": json_data['orbital_period'],
            "gravity": json_data['gravity'],
            "population": json_data['population'],
            "climate": json_data['climate'],
            "terrain": json_data['terrain'],
            "surface_water": json_data['surface_water'],
            "residents": utils.get_resources_dict(
                json_data['residents'],
                'name'),
            "films": utils.get_resources_dict(
                json_data['films'],
                'title'),
        }

        planet = Planet(**planet_response)
        yield planet.json(ensure_ascii=False, encoder='utf-8')

    def get_planets_by_name(name):
        """
        Returns a planet on the Star Wars movies by searching name.
        """
        json_data = get(
            settings.BASE_URL +
            settings.PLANETS +
            settings.SEARCH +
            name).json()

        if not json_data['results']:
            raise SystemExit('Resource does not exist!')

        for json_dict in json_data['results']:
            planet_response = {
                "name": json_dict['name'],
                "diameter": json_dict['diameter'],
                "rotation_period": json_dict['rotation_period'],
                "orbital_period": json_dict['orbital_period'],
                "gravity": json_dict['gravity'],
                "population": json_dict['population'],
                "climate": json_dict['climate'],
                "terrain": json_dict['terrain'],
                "surface_water": json_dict['surface_water'],
                "residents": utils.get_resources_dict(
                    json_dict['residents'],
                    'name'),
                "films": utils.get_resources_dict(
                    json_dict['films'],
                    'title'),
            }

        planet = Planet(**planet_response)
        yield planet.json(ensure_ascii=False, encoder='utf-8')



try:
    import swcli.settings as settings
    import swcli.utils as utils
    from swcli.models import Starship
except:
    import settings
    import utils
    from models import Starship
from httpx import get


class GetStarship(object):
    def get_starship_by_id(starship_id):
        """
        Return a one starship on Star Wars trilogies by ID.
        """
        response = get(
            settings.BASE_URL +
            settings.STARSHIPS +
            str(starship_id))

        if response.status_code != 200:
            raise SystemExit('Resource does not exist!')

        json_data = response.json()

        starships_response = {
            "name": json_data['name'],
            "model": json_data['model'],
            "starship_class": json_data['starship_class'],
            "manufacturer": json_data['manufacturer'],
            "cost": json_data['cost_in_credits'],
            "length": json_data['length'],
            "crew": json_data['crew'],
            "passengers": json_data['passengers'],
            "max_atmosphering_speed": json_data['max_atmosphering_speed'],
            "hyperdrive_rating": json_data['hyperdrive_rating'],
            "mglt": json_data['MGLT'],
            "cargo_capacity": json_data['cargo_capacity'],
            "consumables": json_data['consumables'],
            "films": utils.get_resources_dict(
                json_data['films'],
                'title'),
            "pilots": utils.get_resources_dict(
                json_data['pilots'],
                'name'),
        }

        starship = Starship(**starships_response)
        yield starship.json(ensure_ascii=False, encoder='utf-8')

    def get_starship_by_name(name):
        """
        Return a Starships on Star Wars universe.
        Like: Death Star, Millenium Falcon, etc.
        """
        json_data = get(
            settings.BASE_URL +
            settings.STARSHIPS +
            settings.SEARCH +
            name).json()

        if not json_data['results']:
            raise SystemExit('Resource does not exist!')

        for json_dict in json_data['results']:

            starships_response = {
                "name": json_dict['name'],
                "model": json_dict['model'],
                "starship_class": json_dict['starship_class'],
                "manufacturer": json_dict['manufacturer'],
                "cost": json_dict['cost_in_credits'],
                "length": json_dict['length'],
                "crew": json_dict['crew'],
                "passengers": json_dict['passengers'],
                "max_atmosphering_speed": json_dict['max_atmosphering_speed'],
                "hyperdrive_rating": json_dict['hyperdrive_rating'],
                "mglt": json_dict['MGLT'],
                "cargo_capacity": json_dict['cargo_capacity'],
                "consumables": json_dict['consumables'],
                "films": utils.get_resources_dict(
                    json_dict['films'],
                    'title'),
                "pilots": utils.get_resources_dict(
                    json_dict['pilots'],
                    'name'),
            }

            starship = Starship(**starships_response)
            yield starship.json(ensure_ascii=False, encoder='utf-8')
